@@ -96,6 +96,41 @@ class LinuxFCTestCase(base.TestCase):
         expected = [['0', '1', 1]]
         self.assertListEqual(expected, res)
 
+    def test__get_hba_channel_scsi_target_with_initiator_target_map(self):
+        execute_results = ('/sys/class/fc_transport/target6:0:1/port_name\n',
+                           '')
+        hbas, con_props = self.__get_rescan_info(zone_manager=True)
+        con_props['target_wwn'] = con_props['target_wwn'][0]
+        con_props['targets'] = con_props['targets'][0:1]
+        hbas[0]['port_name'] = '50014380186af83e'
+        with mock.patch.object(self.lfc, '_execute',
+                               return_value=execute_results) as execute_mock:
+            res = self.lfc._get_hba_channel_scsi_target(hbas[0], con_props)
+            execute_mock.assert_called_once_with(
+                'grep -Gil "514f0c50023f6c01" '
+                '/sys/class/fc_transport/target6:*/port_name',
+                shell=True)
+        expected = [['0', '1', 1]]
+        self.assertListEqual(expected, res)
+
+    def test__get_hba_channel_scsi_target_with_initiator_target_map_none(self):
+        execute_results = ('/sys/class/fc_transport/target6:0:1/port_name\n',
+                           '')
+        hbas, con_props = self.__get_rescan_info()
+        con_props['target_wwn'] = con_props['target_wwn'][0]
+        con_props['targets'] = con_props['targets'][0:1]
+        con_props['initiator_target_map'] = None
+        hbas[0]['port_name'] = '50014380186af83e'
+        with mock.patch.object(self.lfc, '_execute',
+                               return_value=execute_results) as execute_mock:
+            res = self.lfc._get_hba_channel_scsi_target(hbas[0], con_props)
+            execute_mock.assert_called_once_with(
+                'grep -Gil "514f0c50023f6c00" '
+                '/sys/class/fc_transport/target6:*/port_name',
+                shell=True)
+        expected = [['0', '1', 1]]
+        self.assertListEqual(expected, res)
+
     def test__get_hba_channel_scsi_target_multiple_wwpn(self):
         execute_results = [
             ['/sys/class/fc_transport/target6:0:1/port_name\n', ''],
@@ -260,33 +295,6 @@ class LinuxFCTestCase(base.TestCase):
                               mock.call(hbas[1], con_props)]
             mock_get_chan.assert_has_calls(expected_calls)
 
-    def test_rescan_hosts_initiator_map_single_wwnn(self):
-        """Test FC rescan with initiator map and single WWNN."""
-        get_chan_results = [[['2', '3', 1], ['4', '5', 1]], [['-', '-', 1]]]
-
-        hbas, con_props = self.__get_rescan_info(zone_manager=True)
-
-        with mock.patch.object(self.lfc, '_execute',
-                               return_value=None) as execute_mock, \
-            mock.patch.object(self.lfc, '_get_hba_channel_scsi_target',
-                              side_effect=get_chan_results) as mock_get_chan:
-
-            self.lfc.rescan_hosts(hbas, con_props)
-            expected_commands = [
-                mock.call('tee', '-a', '/sys/class/scsi_host/host6/scan',
-                          process_input='2 3 1',
-                          root_helper=None, run_as_root=True),
-                mock.call('tee', '-a', '/sys/class/scsi_host/host6/scan',
-                          process_input='4 5 1',
-                          root_helper=None, run_as_root=True)]
-
-            execute_mock.assert_has_calls(expected_commands)
-            self.assertEqual(len(expected_commands), execute_mock.call_count)
-
-            expected_calls = [mock.call(hbas[0], con_props),
-                              mock.call(hbas[1], con_props)]
-            mock_get_chan.assert_has_calls(expected_calls)
-
     def test_rescan_hosts_wildcard(self):
         """Test when we don't have initiator map or target is single WWNN."""
         get_chan_results = [[['-', '-', 1]], [['-', '-', 1]]]
